@@ -18,23 +18,18 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
+#include "libavutil/attributes.h"
 #include "libavutil/mips/cpu.h"
 #include "xvididct_mips.h"
 
-av_cold void ff_xvid_idct_init_mips(IDCTDSPContext *c, AVCodecContext *avctx,
-        unsigned high_bit_depth)
+av_cold void ff_xvid_idct_init_mips(IDCTDSPContext *c)
 {
     int cpu_flags = av_get_cpu_flags();
 
     if (have_mmi(cpu_flags)) {
-        if (!high_bit_depth) {
-            if (avctx->idct_algo == FF_IDCT_AUTO ||
-                    avctx->idct_algo == FF_IDCT_XVID) {
-                c->idct_put = ff_xvid_idct_put_mmi;
-                c->idct_add = ff_xvid_idct_add_mmi;
-                c->idct = ff_xvid_idct_mmi;
-                c->perm_type = FF_IDCT_PERM_NONE;
-            }
-        }
+        c->idct_put  = ff_xvid_idct_put_mmi;
+        c->idct_add  = ff_xvid_idct_add_mmi;
+        c->idct      = ff_xvid_idct_mmi;
+        c->perm_type = FF_IDCT_PERM_NONE;
     }
 }
